@@ -63,10 +63,7 @@ if TYPE_CHECKING:
         IsAuthorizedPoolRequest,
         IsAuthorizedVariableRequest,
     )
-    from airflow.auth.managers.models.resource_details import (
-        ConfigurationDetails,
-        DatasetDetails,
-    )
+    from airflow.auth.managers.models.resource_details import AssetDetails, ConfigurationDetails
     from airflow.providers.amazon.aws.auth_manager.user import AwsAuthManagerUser
     from airflow.www.extensions.init_appbuilder import AirflowAppBuilder
 
@@ -161,15 +158,12 @@ class AwsAuthManager(BaseAuthManager):
             context=context,
         )
 
-    def is_authorized_dataset(
-        self, *, method: ResourceMethod, details: DatasetDetails | None = None, user: BaseUser | None = None
+    def is_authorized_asset(
+        self, *, method: ResourceMethod, details: AssetDetails | None = None, user: BaseUser | None = None
     ) -> bool:
-        dataset_uri = details.uri if details else None
+        asset_uri = details.uri if details else None
         return self.avp_facade.is_authorized(
-            method=method,
-            entity_type=AvpEntities.DATASET,
-            user=user or self.get_user(),
-            entity_id=dataset_uri,
+            method=method, entity_type=AvpEntities.ASSET, user=user or self.get_user(), entity_id=asset_uri
         )
 
     def is_authorized_pool(
