@@ -61,7 +61,7 @@ class AwsAuthManagerAuthenticationViews(AirflowBaseView):
         saml_auth = self._init_saml_auth()
         return redirect(saml_auth.login())
 
-    @expose("/logout")
+    @expose("/logout", methods=("GET", "POST"))
     def logout(self):
         """Start logout process."""
         session.clear()
@@ -93,7 +93,7 @@ class AwsAuthManagerAuthenticationViews(AirflowBaseView):
             user_id=attributes["id"][0],
             groups=attributes["groups"],
             username=saml_auth.get_nameid(),
-            email=attributes["email"][0],
+            email=attributes["email"][0] if "email" in attributes else None,
         )
         session["aws_user"] = user
 
