@@ -44,14 +44,12 @@ import tenacity
 from botocore.config import Config
 from botocore.waiter import Waiter, WaiterModel
 from dateutil.tz import tzlocal
-from deprecated import deprecated
 from slugify import slugify
 
 from airflow.configuration import conf
 from airflow.exceptions import (
     AirflowException,
     AirflowNotFoundException,
-    AirflowProviderDeprecationWarning,
 )
 from airflow.hooks.base import BaseHook
 from airflow.providers.amazon.aws.utils.connection_wrapper import AwsConnectionWrapper
@@ -65,14 +63,29 @@ from airflow.utils.log.secrets_masker import mask_secret
 BaseAwsConnection = TypeVar("BaseAwsConnection", bound=Union[boto3.client, boto3.resource])
 
 if TYPE_CHECKING:
+    from aiobotocore.session import AioSession
     from botocore.client import ClientMeta
     from botocore.credentials import ReadOnlyCredentials
 
-    from airflow.models.connection import Connection  # Avoid circular imports.
+    from airflow.models.connection import Connection
+
+_loader = botocore.loaders.Loader()
+"""
+botocore data loader to be used with async sessions
+
+By default, a botocore session creates and caches an instance of JSONDecoder which
+consumes a lot of memory.  This issue was reported here https://github.com/boto/botocore/issues/3078.
+In the context of triggers which use boto sessions, this can result in excessive
+memory usage and as a result reduced capacity on the triggerer.  We can reduce
+memory footprint by sharing the loader instance across the sessions.
+
+:meta private:
+"""
 
 
 class BaseSessionFactory(LoggingMixin):
-    """Base AWS Session Factory class.
+    """
+    Base AWS Session Factory class.
 
     This handles synchronous and async boto session creation. It can handle most
     of the AWS supported authentication methods.
@@ -154,11 +167,11 @@ class BaseSessionFactory(LoggingMixin):
     def get_async_session(self):
         from aiobotocore.session import get_session as async_get_session
 
-        return async_get_session()
+        session = async_get_session()
+        session.register_component("data_loader", _loader)
+        return session
 
-    def create_session(
-        self, deferrable: bool = False
-    ) -> boto3.session.Session | aiobotocore.session.AioSession:
+    def create_session(self, deferrable: bool = False) -> boto3.session.Session | AioSession:
         """Create boto3 or aiobotocore Session from connection config."""
         if not self.conn:
             self.log.info(
@@ -200,7 +213,7 @@ class BaseSessionFactory(LoggingMixin):
 
     def _create_session_with_assume_role(
         self, session_kwargs: dict[str, Any], deferrable: bool = False
-    ) -> boto3.session.Session | aiobotocore.session.AioSession:
+    ) -> boto3.session.Session | AioSession:
         if self.conn.assume_role_method == "assume_role_with_web_identity":
             # Deferred credentials have no initial credentials
             credential_fetcher = self._get_web_identity_credential_fetcher()
@@ -435,7 +448,8 @@ class BaseSessionFactory(LoggingMixin):
 
 
 class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
-    """Generic class for interact with AWS.
+    """
+    Generic class for interact with AWS.
 
     This class provide a thin wrapper around the boto3 Python library.
 
@@ -497,7 +511,8 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
 
     @staticmethod
     def _find_operator_class_name(target_function_name: str) -> str | None:
-        """Given a frame off the stack, return the name of the class that made the call.
+        """
+        Given a frame off the stack, return the name of the class that made the call.
 
         This method may raise a ValueError or an IndexError. The caller is
         responsible with catching and handling those.
@@ -547,7 +562,8 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
     @staticmethod
     @return_on_error("00000000-0000-0000-0000-000000000000")
     def _generate_dag_key() -> str:
-        """Generate a DAG key.
+        """
+        Generate a DAG key.
 
         The Object Identifier (OID) namespace is used to salt the dag_id value.
         That salted value is used to generate a SHA-1 hash which, by definition,
@@ -783,7 +799,8 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
         return creds
 
     def expand_role(self, role: str, region_name: str | None = None) -> str:
-        """Get the Amazon Resource Name (ARN) for the role.
+        """
+        Get the Amazon Resource Name (ARN) for the role.
 
         If IAM role is already an IAM role ARN, the value is returned unchanged.
 
@@ -861,7 +878,8 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
         }
 
     def test_connection(self):
-        """Test the AWS connection by call AWS STS (Security Token Service) GetCallerIdentity API.
+        """
+        Test the AWS connection by call AWS STS (Security Token Service) GetCallerIdentity API.
 
         .. seealso::
             https://docs.aws.amazon.com/STS/latest/APIReference/API_GetCallerIdentity.html
@@ -898,7 +916,8 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
         deferrable: bool = False,
         client=None,
     ) -> Waiter:
-        """Get a waiter by name.
+        """
+        Get a waiter by name.
 
         First checks if there is a custom waiter with the provided waiter_name and
         uses that if it exists, otherwise it will check the service client for a
@@ -969,7 +988,8 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
 
 
 class AwsBaseHook(AwsGenericHook[Union[boto3.client, boto3.resource]]):
-    """Base class for interact with AWS.
+    """
+    Base class for interact with AWS.
 
     This class provide a thin wrapper around the boto3 Python library.
 
@@ -1006,157 +1026,3 @@ def resolve_session_factory() -> type[BaseSessionFactory]:
 
 
 SessionFactory = resolve_session_factory()
-
-
-def _parse_s3_config(config_file_name: str, config_format: str | None = "boto", profile: str | None = None):
-    """For compatibility with airflow.contrib.hooks.aws_hook."""
-    from airflow.providers.amazon.aws.utils.connection_wrapper import _parse_s3_config
-
-    return _parse_s3_config(
-        config_file_name=config_file_name,
-        config_format=config_format,
-        profile=profile,
-    )
-
-
-try:
-    import aiobotocore.credentials
-    from aiobotocore.session import AioSession, get_session
-except ImportError:
-    pass
-
-
-@deprecated(
-    reason=(
-        "`airflow.providers.amazon.aws.hook.base_aws.BaseAsyncSessionFactory` "
-        "has been deprecated and will be removed in future"
-    ),
-    category=AirflowProviderDeprecationWarning,
-)
-class BaseAsyncSessionFactory(BaseSessionFactory):
-    """
-    Base AWS Session Factory class to handle aiobotocore session creation.
-
-    It currently, handles ENV, AWS secret key and STS client method ``assume_role``
-    provided in Airflow connection
-    """
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    async def get_role_credentials(self) -> dict:
-        """Get the role_arn, method credentials from connection and get the role credentials."""
-        async with self._basic_session.create_client("sts", region_name=self.region_name) as client:
-            response = await client.assume_role(
-                RoleArn=self.role_arn,
-                RoleSessionName=self._strip_invalid_session_name_characters(f"Airflow_{self.conn.conn_id}"),
-                **self.conn.assume_role_kwargs,
-            )
-            return response["Credentials"]
-
-    async def _get_refresh_credentials(self) -> dict[str, Any]:
-        self.log.debug("Refreshing credentials")
-        assume_role_method = self.conn.assume_role_method
-        if assume_role_method != "assume_role":
-            raise NotImplementedError(f"assume_role_method={assume_role_method} not expected")
-
-        credentials = await self.get_role_credentials()
-
-        expiry_time = credentials["Expiration"].isoformat()
-        self.log.debug("New credentials expiry_time: %s", expiry_time)
-        credentials = {
-            "access_key": credentials.get("AccessKeyId"),
-            "secret_key": credentials.get("SecretAccessKey"),
-            "token": credentials.get("SessionToken"),
-            "expiry_time": expiry_time,
-        }
-        return credentials
-
-    def _get_session_with_assume_role(self) -> AioSession:
-        assume_role_method = self.conn.assume_role_method
-        if assume_role_method != "assume_role":
-            raise NotImplementedError(f"assume_role_method={assume_role_method} not expected")
-
-        credentials = aiobotocore.credentials.AioRefreshableCredentials.create_from_metadata(
-            metadata=self._get_refresh_credentials(),
-            refresh_using=self._get_refresh_credentials,
-            method="sts-assume-role",
-        )
-
-        session = aiobotocore.session.get_session()
-        session._credentials = credentials
-        return session
-
-    @cached_property
-    def _basic_session(self) -> AioSession:
-        """Cached property with basic aiobotocore.session.AioSession."""
-        session_kwargs = self.conn.session_kwargs
-        aws_access_key_id = session_kwargs.get("aws_access_key_id")
-        aws_secret_access_key = session_kwargs.get("aws_secret_access_key")
-        aws_session_token = session_kwargs.get("aws_session_token")
-        region_name = session_kwargs.get("region_name")
-        profile_name = session_kwargs.get("profile_name")
-
-        aio_session = get_session()
-        if profile_name is not None:
-            aio_session.set_config_variable("profile", profile_name)
-        if aws_access_key_id or aws_secret_access_key or aws_session_token:
-            aio_session.set_credentials(
-                access_key=aws_access_key_id,
-                secret_key=aws_secret_access_key,
-                token=aws_session_token,
-            )
-        if region_name is not None:
-            aio_session.set_config_variable("region", region_name)
-        return aio_session
-
-    def create_session(self, deferrable: bool = False) -> AioSession:
-        """Create aiobotocore Session from connection and config."""
-        if not self._conn:
-            self.log.info("No connection ID provided. Fallback on boto3 credential strategy")
-            return get_session()
-        elif not self.role_arn:
-            return self._basic_session
-        return self._get_session_with_assume_role()
-
-
-@deprecated(
-    reason=(
-        "`airflow.providers.amazon.aws.hook.base_aws.AwsBaseAsyncHook` "
-        "has been deprecated and will be removed in future"
-    ),
-    category=AirflowProviderDeprecationWarning,
-)
-class AwsBaseAsyncHook(AwsBaseHook):
-    """Interacts with AWS using aiobotocore asynchronously.
-
-    :param aws_conn_id: The Airflow connection used for AWS credentials.
-        If this is None or empty then the default botocore behaviour is used. If
-        running Airflow in a distributed manner and aws_conn_id is None or
-        empty, then default botocore configuration would be used (and must be
-        maintained on each worker node).
-    :param verify: Whether to verify SSL certificates.
-    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
-    :param client_type: boto3.client client_type. Eg 's3', 'emr' etc
-    :param resource_type: boto3.resource resource_type. Eg 'dynamodb' etc
-    :param config: Configuration for botocore client.
-    """
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    def get_async_session(self) -> AioSession:
-        """Get the underlying aiobotocore.session.AioSession(...)."""
-        return BaseAsyncSessionFactory(
-            conn=self.conn_config, region_name=self.region_name, config=self.config
-        ).create_session()
-
-    async def get_client_async(self):
-        """Get the underlying aiobotocore client using aiobotocore session."""
-        return self.get_async_session().create_client(
-            self.client_type,
-            region_name=self.region_name,
-            verify=self.verify,
-            endpoint_url=self.conn_config.endpoint_url,
-            config=self.config,
-        )
