@@ -102,6 +102,8 @@ class BatchProtocol(Protocol):
         arrayProperties: dict,
         parameters: dict,
         containerOverrides: dict,
+        ecsPropertiesOverride: dict,
+        eksPropertiesOverride: dict,
         tags: dict,
     ) -> dict:
         """
@@ -119,6 +121,10 @@ class BatchProtocol(Protocol):
 
         :param containerOverrides: the same parameter that boto3 will receive
 
+        :param ecsPropertiesOverride: the same parameter that boto3 will receive
+
+        :param eksPropertiesOverride: the same parameter that boto3 will receive
+
         :param tags: the same parameter that boto3 will receive
 
         :return: an API response
