@@ -28,7 +28,6 @@ import os
 import re
 import shutil
 import time
-import warnings
 from contextlib import suppress
 from copy import deepcopy
 from datetime import datetime
@@ -41,8 +40,6 @@ from typing import TYPE_CHECKING, Any, AsyncIterator, Callable
 from urllib.parse import urlsplit
 from uuid import uuid4
 
-from airflow.providers.common.compat.lineage.hook import get_hook_lineage_collector
-
 if TYPE_CHECKING:
     from mypy_boto3_s3.service_resource import Bucket as S3Bucket, Object as S3ResourceObject
 
@@ -51,16 +48,25 @@ if TYPE_CHECKING:
     with suppress(ImportError):
         from aiobotocore.client import AioBaseClient
 
+from importlib.util import find_spec
+
 from asgiref.sync import sync_to_async
 from boto3.s3.transfer import S3Transfer, TransferConfig
 from botocore.exceptions import ClientError
 
-from airflow.exceptions import AirflowException, AirflowNotFoundException, AirflowProviderDeprecationWarning
+from airflow.exceptions import AirflowException, AirflowNotFoundException
 from airflow.providers.amazon.aws.exceptions import S3HookUriParseFailure
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.providers.amazon.aws.utils.tags import format_tags
 from airflow.utils.helpers import chunks
 
+if find_spec("airflow.assets"):
+    from airflow.lineage.hook import get_hook_lineage_collector
+else:
+    # TODO: import from common.compat directly after common.compat providers with
+    # asset_compat_lineage_collector released
+    from airflow.providers.amazon.aws.utils.asset_compat_lineage_collector import get_hook_lineage_collector
+
 logger = logging.getLogger(__name__)
 
 
@@ -119,15 +125,6 @@ def provide_bucket_name(func: Callable) -> Callable:
 
                 if "bucket_name" in self.service_config:
                     bound_args.arguments["bucket_name"] = self.service_config["bucket_name"]
-                elif self.conn_config and self.conn_config.schema:
-                    warnings.warn(
-                        "s3 conn_type, and the associated schema field, is deprecated. "
-                        "Please use aws conn_type instead, and specify `bucket_name` "
-                        "in `service_config.s3` within `extras`.",
-                        AirflowProviderDeprecationWarning,
-                        stacklevel=2,
-                    )
-                    bound_args.arguments["bucket_name"] = self.conn_config.schema
 
             return func(*bound_args.args, **bound_args.kwargs)
 
@@ -1113,11 +1110,11 @@ class S3Hook(AwsBaseHook):
 
         client = self.get_conn()
         client.upload_file(filename, bucket_name, key, ExtraArgs=extra_args, Config=self.transfer_config)
-        get_hook_lineage_collector().add_input_dataset(
-            context=self, scheme="file", dataset_kwargs={"path": filename}
+        get_hook_lineage_collector().add_input_asset(
+            context=self, scheme="file", asset_kwargs={"path": filename}
         )
-        get_hook_lineage_collector().add_output_dataset(
-            context=self, scheme="s3", dataset_kwargs={"bucket": bucket_name, "key": key}
+        get_hook_lineage_collector().add_output_asset(
+            context=self, scheme="s3", asset_kwargs={"bucket": bucket_name, "key": key}
         )
 
     @unify_bucket_name_and_key
@@ -1260,8 +1257,8 @@ class S3Hook(AwsBaseHook):
             Config=self.transfer_config,
         )
         # No input because file_obj can be anything - handle in calling function if possible
-        get_hook_lineage_collector().add_output_dataset(
-            context=self, scheme="s3", dataset_kwargs={"bucket": bucket_name, "key": key}
+        get_hook_lineage_collector().add_output_asset(
+            context=self, scheme="s3", asset_kwargs={"bucket": bucket_name, "key": key}
         )
 
     def copy_object(
@@ -1318,11 +1315,11 @@ class S3Hook(AwsBaseHook):
         response = self.get_conn().copy_object(
             Bucket=dest_bucket_name, Key=dest_bucket_key, CopySource=copy_source, **kwargs
         )
-        get_hook_lineage_collector().add_input_dataset(
-            context=self, scheme="s3", dataset_kwargs={"bucket": source_bucket_name, "key": source_bucket_key}
+        get_hook_lineage_collector().add_input_asset(
+            context=self, scheme="s3", asset_kwargs={"bucket": source_bucket_name, "key": source_bucket_key}
         )
-        get_hook_lineage_collector().add_output_dataset(
-            context=self, scheme="s3", dataset_kwargs={"bucket": dest_bucket_name, "key": dest_bucket_key}
+        get_hook_lineage_collector().add_output_asset(
+            context=self, scheme="s3", asset_kwargs={"bucket": dest_bucket_name, "key": dest_bucket_key}
         )
         return response
 
@@ -1443,10 +1440,10 @@ class S3Hook(AwsBaseHook):
 
             file_path.parent.mkdir(exist_ok=True, parents=True)
 
-            get_hook_lineage_collector().add_output_dataset(
+            get_hook_lineage_collector().add_output_asset(
                 context=self,
                 scheme="file",
-                dataset_kwargs={"path": file_path if file_path.is_absolute() else file_path.absolute()},
+                asset_kwargs={"path": file_path if file_path.is_absolute() else file_path.absolute()},
             )
             file = open(file_path, "wb")
         else:
@@ -1458,8 +1455,8 @@ class S3Hook(AwsBaseHook):
                 ExtraArgs=self.extra_args,
                 Config=self.transfer_config,
             )
-        get_hook_lineage_collector().add_input_dataset(
-            context=self, scheme="s3", dataset_kwargs={"bucket": bucket_name, "key": key}
+        get_hook_lineage_collector().add_input_asset(
+            context=self, scheme="s3", asset_kwargs={"bucket": bucket_name, "key": key}
         )
         return file.name
 
