@@ -18,13 +18,12 @@
 from __future__ import annotations
 
 import re
-import warnings
 from datetime import timedelta
 from functools import cached_property
 from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
+from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.exceptions import EcsOperatorError, EcsTaskFailToStart
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.providers.amazon.aws.hooks.ecs import EcsClusterStates, EcsHook, should_retry_eni
@@ -40,7 +39,6 @@ from airflow.providers.amazon.aws.utils.identifiers import generate_uuid
 from airflow.providers.amazon.aws.utils.mixins import aws_template_fields
 from airflow.providers.amazon.aws.utils.task_log_fetcher import AwsTaskLogFetcher
 from airflow.utils.helpers import prune_dict
-from airflow.utils.types import NOTSET
 
 if TYPE_CHECKING:
     import boto3
@@ -258,19 +256,8 @@ class EcsDeregisterTaskDefinitionOperator(EcsBaseOperator):
         self,
         *,
         task_definition: str,
-        wait_for_completion=NOTSET,
-        waiter_delay=NOTSET,
-        waiter_max_attempts=NOTSET,
         **kwargs,
     ):
-        if any(arg is not NOTSET for arg in [wait_for_completion, waiter_delay, waiter_max_attempts]):
-            warnings.warn(
-                "'wait_for_completion' and waiter related params have no effect and are deprecated, "
-                "please remove them.",
-                AirflowProviderDeprecationWarning,
-                stacklevel=2,
-            )
-
         super().__init__(**kwargs)
         self.task_definition = task_definition
 
@@ -311,19 +298,8 @@ class EcsRegisterTaskDefinitionOperator(EcsBaseOperator):
         family: str,
         container_definitions: list[dict],
         register_task_kwargs: dict | None = None,
-        wait_for_completion=NOTSET,
-        waiter_delay=NOTSET,
-        waiter_max_attempts=NOTSET,
         **kwargs,
     ):
-        if any(arg is not NOTSET for arg in [wait_for_completion, waiter_delay, waiter_max_attempts]):
-            warnings.warn(
-                "'wait_for_completion' and waiter related params have no effect and are deprecated, "
-                "please remove them.",
-                AirflowProviderDeprecationWarning,
-                stacklevel=2,
-            )
-
         super().__init__(**kwargs)
         self.family = family
         self.container_definitions = container_definitions
