@@ -18,13 +18,12 @@
 from __future__ import annotations
 
 import json
-import warnings
 from datetime import timedelta
 from functools import cached_property
 from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
+from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.rds import RdsHook
 from airflow.providers.amazon.aws.triggers.rds import (
@@ -36,6 +35,7 @@ from airflow.providers.amazon.aws.utils import validate_execute_complete_event
 from airflow.providers.amazon.aws.utils.rds import RdsDbType
 from airflow.providers.amazon.aws.utils.tags import format_tags
 from airflow.providers.amazon.aws.utils.waiter_with_logging import wait
+from airflow.utils.helpers import prune_dict
 
 if TYPE_CHECKING:
     from mypy_boto3_rds.type_defs import TagTypeDef
@@ -54,30 +54,17 @@ class RdsBaseOperator(BaseOperator):
         *args,
         aws_conn_id: str | None = "aws_conn_id",
         region_name: str | None = None,
-        hook_params: dict | None = None,
         **kwargs,
     ):
-        if hook_params is not None:
-            warnings.warn(
-                "The parameter hook_params is deprecated and will be removed. "
-                "Note that it is also incompatible with deferrable mode. "
-                "You can use the region_name parameter to specify the region. "
-                "If you were using hook_params for other purposes, please get in touch either on "
-                "airflow slack, or by opening a github issue on the project. "
-                "You can mention https://github.com/apache/airflow/pull/32352",
-                AirflowProviderDeprecationWarning,
-                stacklevel=3,  # 2 is in the operator's init, 3 is in the user code creating the operator
-            )
-        self.hook_params = hook_params or {}
         self.aws_conn_id = aws_conn_id
-        self.region_name = region_name or self.hook_params.pop("region_name", None)
+        self.region_name = region_name
         super().__init__(*args, **kwargs)
 
         self._await_interval = 60  # seconds
 
     @cached_property
     def hook(self) -> RdsHook:
-        return RdsHook(aws_conn_id=self.aws_conn_id, region_name=self.region_name, **self.hook_params)
+        return RdsHook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
 
     def execute(self, context: Context) -> str:
         """Different implementations for snapshots, tasks and events."""
@@ -782,7 +769,7 @@ class RdsStartDbOperator(RdsBaseOperator):
                     aws_conn_id=self.aws_conn_id,
                     region_name=self.region_name,
                     response=start_db_response,
-                    db_type=RdsDbType.INSTANCE,
+                    db_type=self.db_type,
                 ),
                 method_name="execute_complete",
             )
@@ -881,12 +868,25 @@ class RdsStopDbOperator(RdsBaseOperator):
                     aws_conn_id=self.aws_conn_id,
                     region_name=self.region_name,
                     response=stop_db_response,
-                    db_type=RdsDbType.INSTANCE,
+                    db_type=self.db_type,
                 ),
                 method_name="execute_complete",
             )
         elif self.wait_for_completion:
-            self._wait_until_db_stopped()
+            waiter = self.hook.get_waiter(f"db_{self.db_type.value}_stopped")
+            waiter_key = (
+                "DBInstanceIdentifier" if self.db_type == RdsDbType.INSTANCE else "DBClusterIdentifier"
+            )
+            kwargs = {waiter_key: self.db_identifier}
+            waiter.wait(
+                WaiterConfig=prune_dict(
+                    {
+                        "Delay": self.waiter_delay,
+                        "MaxAttempts": self.waiter_max_attempts,
+                    }
+                ),
+                **kwargs,
+            )
         return json.dumps(stop_db_response, default=str)
 
     def execute_complete(self, context: Context, event: dict[str, Any] | None = None) -> str:
@@ -915,23 +915,6 @@ class RdsStopDbOperator(RdsBaseOperator):
             response = self.hook.conn.stop_db_cluster(DBClusterIdentifier=self.db_identifier)
         return response
 
-    def _wait_until_db_stopped(self):
-        self.log.info("Waiting for DB %s to reach 'stopped' state", self.db_type.value)
-        if self.db_type == RdsDbType.INSTANCE:
-            self.hook.wait_for_db_instance_state(
-                self.db_identifier,
-                target_state="stopped",
-                check_interval=self.waiter_delay,
-                max_attempts=self.waiter_max_attempts,
-            )
-        else:
-            self.hook.wait_for_db_cluster_state(
-                self.db_identifier,
-                target_state="stopped",
-                check_interval=self.waiter_delay,
-                max_attempts=self.waiter_max_attempts,
-            )
-
 
 __all__ = [
     "RdsCreateDbSnapshotOperator",
