@@ -19,18 +19,12 @@
 
 from __future__ import annotations
 
-import warnings
 from typing import Sequence
 
-from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.utils.types import NOTSET, ArgNotSet
 
-_DEPRECATION_MSG = (
-    "The aws_conn_id parameter has been deprecated. Use the source_aws_conn_id parameter instead."
-)
-
 
 class AwsToAwsBaseOperator(BaseOperator):
     """
@@ -43,8 +37,6 @@ class AwsToAwsBaseOperator(BaseOperator):
         would be used (and must be maintained on each worker node).
     :param dest_aws_conn_id: The Airflow connection used for AWS credentials
         to access S3. If this is not set then the source_aws_conn_id connection is used.
-    :param aws_conn_id: The Airflow connection used for AWS credentials (deprecated; use source_aws_conn_id).
-
     """
 
     template_fields: Sequence[str] = (
@@ -57,17 +49,12 @@ class AwsToAwsBaseOperator(BaseOperator):
         *,
         source_aws_conn_id: str | None = AwsBaseHook.default_conn_name,
         dest_aws_conn_id: str | None | ArgNotSet = NOTSET,
-        aws_conn_id: str | None | ArgNotSet = NOTSET,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.source_aws_conn_id = source_aws_conn_id
         self.dest_aws_conn_id = dest_aws_conn_id
-        if not isinstance(aws_conn_id, ArgNotSet):
-            warnings.warn(_DEPRECATION_MSG, AirflowProviderDeprecationWarning, stacklevel=3)
-            self.source_aws_conn_id = aws_conn_id
-        else:
-            self.source_aws_conn_id = source_aws_conn_id
+        self.source_aws_conn_id = source_aws_conn_id
         if isinstance(dest_aws_conn_id, ArgNotSet):
             self.dest_aws_conn_id = self.source_aws_conn_id
         else:
